@@ -12,7 +12,7 @@ from rich.logging import RichHandler
 
 from griffon.output import console
 
-__version__ = "0.2.16"
+__version__ = "0.2.17"
 
 if "CORGI_API_URL" not in os.environ:
     print("Must set CORGI_API_URL environment variable.")
@@ -72,9 +72,7 @@ griffon_config = get_config()
 def get_config_option(section, option, default_value=None):
     if griffon_config.has_option(section, option):
         return griffon_config.get(section, option)
-    if default_value:
-        return default_value
-    return None
+    return default_value
 
 
 def list_config_sections():
