@@ -27,7 +27,7 @@ class product_stream_summary:
 
     name = "product_stream_summary"
     description = "retrieve product_stream summary"
-    allowed_params = ["strict_name_search", "all", "product_stream_name", "ofuri"]
+    allowed_params = ["strict_name_search", "all", "product_stream_name", "ofuri", "verbose"]
 
     def __init__(self, params: dict) -> None:
         self.corgi_session = CorgiService.create_session()
@@ -55,6 +55,7 @@ class product_stream_summary:
             limit=400,
             include_fields="link,ofuri,name,products,product_versions,brew_tags,manifest",
         )
+
         results = []
         if product_streams.results:
             for ps in product_streams.results:
@@ -63,7 +64,7 @@ class product_stream_summary:
                     "ofuri": ps.ofuri,
                     "name": ps.name,
                     "product": ps.products[0]["name"],
-                    "product_version": ps.product_versions[0]["name"],
+                    "product_version": str([pv["name"] for pv in ps.product_versions]),
                     "brew_tags": [brew_tag for brew_tag in ps.brew_tags.to_dict().keys()],
                     # "build_count": ps.build_count,
                     "manifest_link": ps.manifest,
@@ -72,18 +73,21 @@ class product_stream_summary:
                 }
                 results.append(result)
         else:
-            result = {
-                "link": product_streams["link"],
-                "ofuri": product_streams["ofuri"],
-                "name": product_streams["name"],
-                "product": product_streams["products"][0]["name"],
-                "product_version": product_streams["product_versions"][0]["name"],
-                "brew_tags": "",
-                "manifest_link": product_streams["manifest"],
-                "latest_components_link": f"{CORGI_API_URL}/api/v1/components?ofuri={product_streams['ofuri']}&view=summary",  # noqa
-                "all_components_link": f"{CORGI_API_URL}/api/v1/components?product_streams={product_streams['ofuri']}&include_fields=link,name,purl",  # noqa
-            }
-            results.append(result)
+            if "ofuri" in product_streams:
+                result = {
+                    "link": product_streams["link"],
+                    "ofuri": product_streams["ofuri"],
+                    "name": product_streams["name"],
+                    "product": product_streams["products"][0]["name"],
+                    "product_version": product_streams["product_versions"][0]["name"],
+                    "brew_tags": "",
+                    "manifest_link": product_streams["manifest"],
+                    "latest_components_link": f"{CORGI_API_URL}/api/v1/components?ofuri={product_streams['ofuri']}&view=summary",  # noqa
+                    "all_components_link": f"{CORGI_API_URL}/api/v1/components?product_streams={product_streams['ofuri']}&include_fields=link,name,purl",  # noqa
+                }
+                results.append(result)
+            else:
+                logger.warning("No such product stream")
         return results
 
 
@@ -132,7 +136,8 @@ class products_versions_affected_by_specific_cve_query:
                     executor.submit(
                         self.corgi_session.components.retrieve_list,
                         name=affect.ps_component,
-                        view="latest",
+                        latest_components_by_streams=True,
+                        include_fields="product_streams.name,product_versions.name",
                     )
                 )
             for future in concurrent.futures.as_completed(futures):
@@ -144,8 +149,10 @@ class products_versions_affected_by_specific_cve_query:
                     exit(0)
 
             for c in results:
-                product_streams.add(c["product_stream"])
-                product_versions.add(c["product_version"])
+                for ps in c["product_streams"]:
+                    product_streams.add(ps["name"])
+                for pv in c["product_versions"]:
+                    product_versions.add(ps["name"])
         return {
             "link": f"{OSIDB_API_URL}/osidb/api/v1/flaws/{flaw.cve_id}",
             "cve_id": flaw.cve_id,
@@ -172,10 +179,17 @@ class products_containing_specific_component_query:
         "affect_mode",
         "search_latest",
         "search_all",
+        "search_all_roots",
         "search_related_url",
         "search_community",
         "search_upstreams",
         "filter_rh_naming",
+        "search_redhat",
+        "no_community",
+        "no_middleware",
+        "include_inactive_product_streams",
+        "include_product_stream_excluded_components",
+        "output_type_filter",
     ]
 
     def __init__(self, params: dict) -> None:
@@ -190,6 +204,31 @@ class products_containing_specific_component_query:
         return c["product_streams"]
 
 
+def async_retrieve_components(corgi_session, params, components_initial, component_cnt):
+    components = list()
+    if component_cnt < 120:
+        components.extend(components_initial.results)
+    elif component_cnt > 120:
+        components.extend(components_initial.results)
+        with concurrent.futures.ThreadPoolExecutor() as executor:
+            futures = []
+            for batch in range(120, 1200, 120):
+                futures.append(
+                    executor.submit(
+                        corgi_session.components.retrieve_list,
+                        **params,
+                        offset=batch,
+                        limit=120,  # noqa
+                    )
+                )
+            for future in concurrent.futures.as_completed(futures):
+                try:
+                    components.extend(future.result().results)
+                except Exception as exc:
+                    logger.warning("%r generated an exception: %s" % (future, exc))
+    return components
+
+
 class products_containing_component_query:
     """What products contain a component?"""
 
@@ -204,289 +243,140 @@ class products_containing_component_query:
         "strict_name_search",
         "search_latest",
         "search_all",
+        "search_all_roots",
         "search_related_url",
+        "search_redhat",
         "search_community",
         "search_upstreams",
         "filter_rh_naming",
+        "no_community",
+        "no_middleware",
+        "include_inactive_product_streams",
+        "include_product_stream_excluded_components",
+        "output_type_filter",
     ]
 
     def __init__(self, params: dict) -> None:
         self.corgi_session = CorgiService.create_session()
         self.params = params
-        self.component_name = self.params.get("component_name")
-        self.component_type = self.params.get("component_type")
+        self.component_name = self.params.get("component_name", "")
+        self.component_type = self.params.get("component_type", "")
         self.strict_name_search = self.params.get("strict_name_search")
         self.search_deps = self.params.get("search_deps")
         self.ns = self.params.get("namespace")
         self.search_latest = self.params.get("search_latest")
         self.search_all = self.params.get("search_all")
+        self.search_all_roots = self.params.get("search_all_roots")
         self.search_related_url = self.params.get("search_related_url")
+        self.search_redhat = self.params.get("search_redhat")
         self.search_community = self.params.get("search_community")
         self.search_upstreams = self.params.get("search_upstreams")
         self.filter_rh_naming = self.params.get("filter_rh_naming")
+        self.no_community = self.params.get("no_community")
 
     def execute(self) -> List[Dict[str, Any]]:
         results = []
+        params = {
+            "include_fields": "link,purl,type,name,related_url,namespace,software_build,nvr,sources.nvr,sources.purl,sources.name,sources.namespace,sources.download_url,sources.related_url,upstreams.nvr,upstreams.purl,upstreams.namespace,upstreams.name,upstreams.download_url,upstreams.related_url,release,version,arch,product_streams.product_versions,product_streams.name,product_streams.ofuri,product_streams.active,product_streams.exclude_components",  # noqa
+        }
+
         if self.search_latest:
-            cond = {"view": "latest"}
-            if not self.strict_name_search:
-                cond["re_name"] = self.component_name  # type: ignore
-            else:
-                cond["name"] = self.component_name  # type: ignore
-            cond["namespace"] = "REDHAT"
-            result = self.corgi_session.components.retrieve_list(**cond)
-            results = result.results
-            # TODO: this should be done server side at some point
-            if self.component_type:
-                results = [result for result in results if result.type == self.component_type]
-
-        if self.search_related_url:
-            # Note: related_url filter has no concept of strict
-            params = {
-                "include_fields": "name,arch,release,version,nvr,type,link,software_build,product_versions,product_streams,sources,upstreams,namespace,purl",  # noqa
-                "arch": "src",
-                "related_url": self.component_name,
-            }
-            params["namespace"] = "REDHAT"
-            if self.component_type:
-                params["type"] = self.component_type
-
-            component_cnt = self.corgi_session.components.retrieve_list(**params).count
-            if component_cnt < 3000000:
-                with concurrent.futures.ThreadPoolExecutor() as executor:
-                    futures = []
-                    components = list()
-                    for batch in range(0, component_cnt, 120):
-                        futures.append(
-                            executor.submit(
-                                self.corgi_session.components.retrieve_list,
-                                **params,
-                                offset=batch,
-                                limit=120,  # noqa
-                            )
-                        )
-                    params["arch"] = "noarch"
-                    component_cnt = self.corgi_session.components.retrieve_list(**params).count
-                    for batch in range(0, component_cnt, 120):
-                        futures.append(
-                            executor.submit(
-                                self.corgi_session.components.retrieve_list,
-                                **params,
-                                offset=batch,
-                                limit=120,  # noqa
-                            )
-                        )
-
-                    for future in concurrent.futures.as_completed(futures):
-                        try:
-                            components.extend(future.result().results)
-                        except Exception as exc:
-                            logger.warning("%r generated an exception: %s" % (future, exc))
-
-                    for c in components:
-                        if self.strict_name_search:
-                            if c.name != self.component_name:
-                                continue
-                        for pv in c.product_versions:
-                            for ps in c.product_streams:
-                                is_dep = False
-                                if c.arch == "src" or c.arch == "noarch":
-                                    is_dep = True
-                                component = {
-                                    "is_dep": is_dep,
-                                    "product_version": pv["name"],
-                                    "product_version_ofuri": pv["ofuri"],
-                                    "product_stream": ps["name"],
-                                    "product_stream_ofuri": ps["ofuri"],
-                                    "product_active": True,
-                                    "purl": c.purl,
-                                    "type": c.type,
-                                    "namespace": c.namespace,
-                                    "name": c.name,
-                                    "arch": c.arch,
-                                    "release": c.release,
-                                    "version": c.version,
-                                    "sources": c.sources,
-                                    "nvr": c.nvr,
-                                    "build_id": None,
-                                    "build_type": None,
-                                    "build_source_url": None,
-                                    "related_url": None,
-                                    "upstream_purl": None,
-                                }
-                                if c.software_build:
-                                    component["build_id"] = c.software_build.build_id
-                                    component["build_type"] = c.software_build.build_type
-                                    component["build_name"] = c.software_build.name
-                                    component["build_source_url"] = c.software_build.source
-                                if c.upstreams:
-                                    component["upstream_purl"] = c.upstreams[0]["purl"]
-                                results.append(component)
-
-        if self.search_all:
-            params = {
-                "include_fields": "name,arch,release,version,nvr,type,link,software_build,product_versions,product_streams,sources,upstreams,namespace,purl",  # noqa
-                "arch": "src",
-            }
+            params["latest_components_by_streams"] = "True"
             if not self.strict_name_search:
                 params["re_name"] = self.component_name
             else:
                 params["name"] = self.component_name
+            if self.ns:
+                params["namespace"] = self.ns
 
+            component_initial = self.corgi_session.components.retrieve_list(limit=120, **params)
+            latest_components: list = async_retrieve_components(
+                self.corgi_session, params, component_initial, component_initial.count
+            )
+            results.extend(latest_components)
+
+        if self.search_related_url:
+            # Note: related_url filter has no concept of strict
+            params["related_url"] = self.component_name
+            if self.ns:
+                params["namespace"] = self.ns
             if self.component_type:
                 params["type"] = self.component_type
 
-            component_cnt = self.corgi_session.components.retrieve_list(**params).count
-            if component_cnt < 3000000:
-                with concurrent.futures.ThreadPoolExecutor() as executor:
-                    futures = []
-                    components = list()
-                    for batch in range(0, component_cnt, 100):
-                        futures.append(
-                            executor.submit(
-                                self.corgi_session.components.retrieve_list,
-                                **params,
-                                offset=batch,
-                                limit=100,  # noqa
-                            )
-                        )
-                    params["arch"] = "noarch"
-                    component_cnt = self.corgi_session.components.retrieve_list(**params).count
-                    for batch in range(0, component_cnt, 120):
-                        futures.append(
-                            executor.submit(
-                                self.corgi_session.components.retrieve_list,
-                                **params,
-                                offset=batch,
-                                limit=120,  # noqa
-                            )
-                        )
-                    for future in concurrent.futures.as_completed(futures):
-                        try:
-                            components.extend(future.result().results)
-                        except Exception as exc:
-                            logger.warning("%r generated an exception: %s" % (future, exc))
+            component_initial = self.corgi_session.components.retrieve_list(limit=120, **params)
+            related_url_components: list = async_retrieve_components(
+                self.corgi_session, params, component_initial, component_initial.count
+            )
+            results.extend(related_url_components)
 
-                    for c in components:
-                        for pv in c.product_versions:
-                            for ps in c.product_streams:
-                                is_dep = False
-                                if c.arch == "src" or c.arch == "noarch":
-                                    is_dep = True
-                                component = {
-                                    "is_dep": is_dep,
-                                    "product_version": pv["name"],
-                                    "product_version_ofuri": pv["ofuri"],
-                                    "product_stream": ps["name"],
-                                    "product_stream_ofuri": ps["ofuri"],
-                                    "product_active": True,
-                                    "purl": c.purl,
-                                    "type": c.type,
-                                    "namespace": c.namespace,
-                                    "name": c.name,
-                                    "arch": c.arch,
-                                    "release": c.release,
-                                    "version": c.version,
-                                    "sources": c.sources,
-                                    "nvr": c.nvr,
-                                    "build_id": None,
-                                    "build_type": None,
-                                    "build_source_url": None,
-                                    "related_url": None,
-                                    "upstream_purl": None,
-                                }
-                                if c.software_build:
-                                    component["build_id"] = c.software_build.build_id
-                                    component["build_type"] = c.software_build.build_type
-                                    component["build_name"] = c.software_build.name
-                                    component["build_source_url"] = c.software_build.source
-                                if c.upstreams:
-                                    component["upstream_purl"] = c.upstreams[0]["purl"]
-                                results.append(component)
+        if self.search_all:
+            if not self.strict_name_search:
+                params["re_name"] = self.component_name
+            else:
+                params["name"] = self.component_name
+            if self.component_type:
+                params["type"] = self.component_type
+            if self.ns:
+                params["namespace"] = self.ns
+
+            all_component_initial = self.corgi_session.components.retrieve_list(limit=120, **params)
+            all_components: list = async_retrieve_components(
+                self.corgi_session,
+                params,
+                all_component_initial,
+                all_component_initial.count,
+            )
+            results.extend(all_components)
+
+        if self.search_all_roots:
+            params["type"] = "RPM"
+            params["arch"] = "src"
+            if not self.strict_name_search:
+                params["re_name"] = self.component_name
+            else:
+                params["name"] = self.component_name
+            if self.ns:
+                params["namespace"] = self.ns
+
+            all_src_component_initial = self.corgi_session.components.retrieve_list(
+                limit=120, **params
+            )
+            all_src_components: list = async_retrieve_components(
+                self.corgi_session,
+                params,
+                all_src_component_initial,
+                all_src_component_initial.count,
+            )
+            params["type"] = "OCI"
+            params["arch"] = "noarch"
+            all_noarch_component_initial = self.corgi_session.components.retrieve_list(
+                limit=120, **params
+            )
+            all_noarch_components: list = async_retrieve_components(
+                self.corgi_session,
+                params,
+                all_noarch_component_initial,
+                all_noarch_component_initial.count,
+            )
+            all_root_components = all_src_components + all_noarch_components
+            results.extend(all_root_components)
 
         if self.search_upstreams:
             # Note: upstreams only takes a purl ... so we must use re_upstreams for
             # both strict and not strict search
-            params = params = {
-                "include_fields": "name,arch,release,version,nvr,type,link,software_build,product_versions,product_streams,sources,upstreams,namespace,purl",  # noqa
-                "arch": "src",
-                "re_upstreams": self.component_name,
-            }
+            params["namespace"] = "UPSTREAM"
+            if not self.strict_name_search:
+                params["re_name"] = self.component_name
+            else:
+                params["name"] = self.component_name
             if self.component_type:
                 params["type"] = self.component_type
 
-            component_cnt = self.corgi_session.components.retrieve_list(**params).count
-            if component_cnt < 3000000:
-                with concurrent.futures.ThreadPoolExecutor() as executor:
-                    # search src and noarch
-                    futures = []
-                    components = list()
-                    for batch in range(0, component_cnt, 120):
-                        futures.append(
-                            executor.submit(
-                                self.corgi_session.components.retrieve_list,
-                                **params,
-                                offset=batch,
-                                limit=120,  # noqa
-                            )
-                        )
-                    params["arch"] = "noarch"
-                    component_cnt = self.corgi_session.components.retrieve_list(**params).count
-                    for batch in range(0, component_cnt, 120):
-                        futures.append(
-                            executor.submit(
-                                self.corgi_session.components.retrieve_list,
-                                **params,
-                                offset=batch,
-                                limit=120,  # noqa
-                            )
-                        )
-
-                    for future in concurrent.futures.as_completed(futures):
-                        try:
-                            components.extend(future.result().results)
-                        except Exception as exc:
-                            logger.warning("%r generated an exception: %s" % (future, exc))
-
-                    for c in components:
-                        if self.strict_name_search:
-                            if c.name != self.component_name:
-                                continue
-                        for pv in c.product_versions:
-                            for ps in c.product_streams:
-                                is_dep = False
-                                if c.arch == "src" or c.arch == "noarch":
-                                    is_dep = True
-                                component = {
-                                    "is_dep": is_dep,
-                                    "product_version": pv["name"],
-                                    "product_version_ofuri": pv["ofuri"],
-                                    "product_stream": ps["name"],
-                                    "product_stream_ofuri": ps["ofuri"],
-                                    "product_active": True,
-                                    "purl": c.purl,
-                                    "type": c.type,
-                                    "namespace": c.namespace,
-                                    "name": c.name,
-                                    "arch": c.arch,
-                                    "release": c.release,
-                                    "version": c.version,
-                                    "sources": c.sources,
-                                    "nvr": c.nvr,
-                                    "build_id": None,
-                                    "build_type": None,
-                                    "build_source_url": None,
-                                    "related_url": None,
-                                    "upstream_purl": None,
-                                }
-                                if c.software_build:
-                                    component["build_id"] = c.software_build.build_id
-                                    component["build_type"] = c.software_build.build_type
-                                    component["build_name"] = c.software_build.name
-                                    component["build_source_url"] = c.software_build.source
-                                if c.upstreams:
-                                    component["upstream_purl"] = c.upstreams[0]["purl"]
-                                results.append(component)
+            component_initial = self.corgi_session.components.retrieve_list(limit=120, **params)
+            upstream_components: list = async_retrieve_components(
+                self.corgi_session, params, component_initial, component_initial.count
+            )
+            results.extend(upstream_components)
 
         if self.filter_rh_naming:
             flags = re.IGNORECASE
@@ -527,88 +417,41 @@ class products_containing_component_query:
 
             results = filtered_results
 
-        if self.search_community:
+        if not self.no_community and (
+            self.search_community or self.search_all or self.search_all_roots
+        ):
             self.community_session = CommunityComponentService.create_session()
-
-            params = {
-                "include_fields": "name,arch,release,version,nvr,type,link,software_build,product_versions,product_streams,sources,upstreams,namespace,purl",  # noqa
-                "arch": "src",
-            }
+            params["type"] = "RPM"
+            params["arch"] = "src"
             if not self.strict_name_search:
                 params["re_name"] = self.component_name
             else:
                 params["name"] = self.component_name
+            if self.search_upstreams:
+                params["namespace"] = "UPSTREAM"
+            if self.ns:
+                params["namespace"] = self.ns
 
             if self.component_type:
                 params["type"] = self.component_type
 
-            component_cnt = self.community_session.components.retrieve_list(**params).count
-            if component_cnt < 3000000:
-                with concurrent.futures.ThreadPoolExecutor() as executor:
-                    futures = []
-                    components = list()
-                    for batch in range(0, component_cnt, 100):
-                        futures.append(
-                            executor.submit(
-                                self.community_session.components.retrieve_list,
-                                **params,
-                                offset=batch,
-                                limit=100,  # noqa
-                            )
-                        )
-                    params["arch"] = "noarch"
-                    component_cnt = self.corgi_session.components.retrieve_list(**params).count
-                    for batch in range(0, component_cnt, 120):
-                        futures.append(
-                            executor.submit(
-                                self.community_session.components.retrieve_list,
-                                **params,
-                                offset=batch,
-                                limit=120,  # noqa
-                            )
-                        )
-                    for future in concurrent.futures.as_completed(futures):
-                        try:
-                            components.extend(future.result().results)
-                        except Exception as exc:
-                            logger.warning("%r generated an exception: %s" % (future, exc))
-
-                    for c in components:
-                        for pv in c.product_versions:
-                            for ps in c.product_streams:
-                                is_dep = False
-                                if c.arch == "src" or c.arch == "noarch":
-                                    is_dep = True
-                                component = {
-                                    "is_dep": is_dep,
-                                    "product_version": pv["name"],
-                                    "product_version_ofuri": pv["ofuri"],
-                                    "product_stream": ps["name"],
-                                    "product_stream_ofuri": ps["ofuri"],
-                                    "product_active": True,
-                                    "purl": c.purl,
-                                    "type": c.type,
-                                    "namespace": c.namespace,
-                                    "name": c.name,
-                                    "arch": c.arch,
-                                    "release": c.release,
-                                    "version": c.version,
-                                    "sources": c.sources,
-                                    "nvr": c.nvr,
-                                    "build_id": None,
-                                    "build_type": None,
-                                    "build_source_url": None,
-                                    "related_url": None,
-                                    "upstream_purl": None,
-                                }
-                                if c.software_build:
-                                    component["build_id"] = c.software_build.build_id
-                                    component["build_type"] = c.software_build.build_type
-                                    component["build_name"] = c.software_build.name
-                                    component["build_source_url"] = c.software_build.source
-                                if c.upstreams:
-                                    component["upstream_purl"] = c.upstreams[0]["purl"]
-                                results.append(component)
+            component_initial = self.community_session.components.retrieve_list(limit=120, **params)
+            commmunity_src_components: list = async_retrieve_components(
+                self.community_session, params, component_initial, component_initial.count
+            )
+            params["type"] = "OCI"
+            params["arch"] = "noarch"
+            component_initial_noarch = self.community_session.components.retrieve_list(
+                limit=120, **params
+            )
+            commmunity_noarch_components: list = async_retrieve_components(
+                self.community_session,
+                params,
+                component_initial_noarch,
+                component_initial_noarch.count,
+            )
+            community_components = commmunity_src_components + commmunity_noarch_components
+            results.extend(community_components)
 
         return results
 
@@ -627,6 +470,7 @@ class components_containing_specific_component_query:
         "component_arch",
         "namespace",
         "strict_name_search",
+        "verbose",
     ]
 
     def __init__(self, params: dict):
@@ -666,6 +510,7 @@ class components_containing_component_query:
         "component_arch",
         "namespace",
         "strict_name_search",
+        "verbose",
     ]
 
     def __init__(self, params: dict) -> None:
@@ -788,7 +633,8 @@ class components_affected_by_specific_cve_query:
                     executor.submit(
                         self.corgi_session.components.retrieve_list,
                         name=affect.ps_component,
-                        view="latest",
+                        latest_components_by_streams=True,
+                        include_fields="purl,product_streams,product_versions,software_build",
                     )
                 )
             for future in concurrent.futures.as_completed(futures):
@@ -897,8 +743,8 @@ class cves_for_specific_component_query:
                             {
                                 "link_affect": f"{OSIDB_API_URL}/osidb/api/v1/affects/{affect['uuid']}",  # noqa
                                 "link_cve": f"{OSIDB_API_URL}/osidb/api/v1/flaws/{flaw['cve_id']}",  # noqa
-                                "link_component": f"{CORGI_API_URL}/api/v1/components?name={affect['ps_component']}&view=latest",  # noqa
-                                "link_community_component": f"{COMMUNITY_COMPONENTS_API_URL}/api/v1/components?name={affect['ps_component']}&view=latest",  # noqa
+                                "link_component": f"{CORGI_API_URL}/api/v1/components?name={affect['ps_component']}&latest_components_by_streams=True",  # noqa
+                                "link_community_component": f"{COMMUNITY_COMPONENTS_API_URL}/api/v1/components?name={affect['ps_component']}&latest_components_by_streams=True",  # noqa
                                 "flaw_cve_id": flaw["cve_id"],
                                 "title": flaw["title"],
                                 "flaw_state": flaw["state"],
@@ -1010,8 +856,8 @@ class cves_for_specific_product_query:
                             {
                                 "link_affect": f"{OSIDB_API_URL}/osidb/api/v1/affects/{affect['uuid']}",  # noqa
                                 "link_cve": f"{OSIDB_API_URL}/osidb/api/v1/flaws/{flaw['cve_id']}",  # noqa
-                                "link_component": f"{CORGI_API_URL}/api/v1/components?name={affect['ps_component']}&view=latest",  # noqa
-                                "link_community_component": f"{COMMUNITY_COMPONENTS_API_URL}/api/v1/components?name={affect['ps_component']}&view=latest",  # noqa
+                                "link_component": f"{CORGI_API_URL}/api/v1/components?name={affect['ps_component']}&latest_components_by_streams=True",  # noqa
+                                "link_community_component": f"{COMMUNITY_COMPONENTS_API_URL}/api/v1/components?name={affect['ps_component']}&latest_components_by_streams=True",  # noqa
                                 "flaw_cve_id": flaw["cve_id"],
                                 "title": flaw["title"],
                                 "flaw_state": flaw["state"],
